* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files                                                        *
* Master .do file                                                              *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil
* Program Purpose: This master dofile runs all necessary dofiles to reproduce
*                  the analysis presented in the paper "Women's Labor Force 
*                  Participation in Nepal: An Exploration of The Role of 
*                  Social Norms" 
* Date last modified: May 2024
*------------------------------------------------------------------------------*
* Datasets Required: [List the required datasets here, if applicable]
*
* Unique Identificator: [Specify if there's any unique identifier for the datasets]
*
* Outline: 
*  01. Data Cleaning 
*  02. Constructing Data Variables for Analysis 
*  03. Data Analysis - Reproducing Descriptive Statistics, Regression 
*      Tables, and Data for Graphs as included in the Working Paper.
*/

********************************************************************************
*                     PREPARATION AND MAIN SETTINGS                            *
********************************************************************************

if 1 {
	
* ------------------------------------------------------------------------------
* Root Folder Globals - Define User and Paths:
* ------------------------------------------------------------------------------
   if 1 {
      
   * Define OneDrive Paths for Each User:
   * ------------------------------------
     gl onedrive "C:/WBG/rep-checks/RR_NPL_2024_147"
      
   * Define Project Folder Globals:
   * -------------------------------
     gl data          "$onedrive/data"
     gl dofiles       "$onedrive/dofiles"
     gl output 		  "$onedrive/output" 
   

* ------------------------------------------------------------------------------
* Standardize Settings Across Users:
* ------------------------------------------------------------------------------
  sysdir set PLUS "${dofiles}/ado"
  ieboilstart, version(14.0) matsize(11000)
  `r(version)'   
  //set abbrev on

* ------------------------------------------------------------------------------
* List of required Packages (already included in the ado folder, there's no need to run this):
* ------------------------------------------------------------------------------
if 0 {
   *ssc install ietoolkit, replace
   *ssc install outreg2, replace
   *ssc install schemepack, replace  
}

* ------------------------------------------------------------------------------
*  Define Sections to Execute:                                                 *
* ------------------------------------------------------------------------------
   local paper_name 	  "SocialNormsFLFPNepal"   
   local DataCleaning     1   
   local DataConstruction 1
   local DataAnalysis     1   
}   
  

********************************************************************************
*                   01. DATA PREPARATION AND CLEANING                          *
******************************************************************************** 
if (`DataCleaning' == 1) { 
	do "$dofiles/clean/01_DataCleaning.do"
}
  
********************************************************************************
*                  02. DATA VARIABLE CONSTRUCTION                              *
******************************************************************************** 
if (`DataConstruction' == 1) { 
   do "$dofiles/prepare/02_DataConstruction.do"
}

********************************************************************************
*                    03. DATA ANALYSIS                                         *
******************************************************************************** 
if (`DataAnalysis' == 1) { 
   do "$dofiles/analyze/03_MasterDataAnalysis.do"
}

********************************************************************************
// END OF DOFILE
