* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files 													   * 
* 03a: Data Analysis .do file                                                  *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil
* Program Purpose: This dofile reproduces analyses reported in the main body
*                  of the paper. 
* Description: Key tasks performed by this dofile include:
- Generates tables and figures included in the main body of the paper.  
*
* Date last modified: May 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - NPL_SN_REGRESS
*
* Unique Identificator:
* - ID
* - ID_HH
*
* Outline: 
*  Part 1. Generate tables included in the main body of the paper.  
*  Part 2. Generate figures included in the main body of the paper.  
*/


********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1{   
	
   local part_1    1    // Set to 1 to generate tables; 0 to skip 
   local part_2    1    // Set to 1 to generate figures; 0 to skip 
  
}


*Load dataset 
 use "$data\final\NPL_SN_REGRESS.dta", clear

********************************************************************************
*                       Part 1. TABLES 							               *
********************************************************************************
if (`part_1' == 1) { 
 
*** Table 1 *** 
 //Code not applicable; this is a text-only table.
 
*** Table 2 *** 
 putexcel set "$output\main\tables\table2.xls", replace 
 
 putexcel A1=("Indicators") B1=("Female (%)") C1=("Male (%)") ///
 A2=("Education") A3=("No education") A4=("Some basic") A5=("Basic complete (complete grade 8)") ///
 A6=("Some secondary (start grade 9 or 10) or complete(pass S.E.E/S.L.C.)") ///
 A7=("Some higher secondary (start grade 11 or 12) or complete (pass H.S.E.B final)") ///
 A8=("Diploma/bachelor's complete or higher") A9=("Worked in 30 days preceding the survey") ///
 A10=("Worked in 7 days preceding the survey") A11=("Work status of all respondents") ///
 A12=("Self-employed") A13=("Salaried/wage employee") A14=("Unpaid worker in the family business") ///
 A15=("Does not work and not looking for work") A16=("Does not work but is looking for work") ///
 A17=("Reasons for not working, among non-working respondents (multiple responses)") ///
 A18=("Illness, injury, or disability") A19=("Childcare, no other options I trust") A20=("Eldercare") ///
 A21=("Household chores, no one to take over") A22=("No support from family") ///
 A23=("No suitable jobs available") A24=("Other")
 
 count if female == 1
 local valf = r(N)
 count if female == 0
 local valm = r(N)

//education 
 count if female==1 & education==1
 local valf1_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B3=("`valf1_perc'")  
 
 count if female==1 & education==2
 local valf2_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B4=("`valf2_perc'") 
 
 count if female==1 & education==3
 local valf3_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B5=("`valf3_perc'") 
 
 count if female==1 & inlist(education, 4, 5)
 local valf4_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B6=("`valf4_perc'")
 
 count if female==1 & inlist(education, 6, 7)
 local valf5_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B7=("`valf5_perc'")
 
 count if female==1 & inlist(education, 8, 9)
 local valf6_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B8=("`valf6_perc'")
 
 count if female==0 & education==1
 local valm1_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C3=("`valm1_perc'")  
 
 count if female==0 & education==2
 local valm2_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C4=("`valm2_perc'") 
 
 count if female==0 & education==3
 local valm3_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C5=("`valm3_perc'") 
 
 count if female==0 & inlist(education, 4, 5)
 local valm4_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C6=("`valm4_perc'")
 
 count if female==0 & inlist(education, 6, 7)
 local valm5_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C7=("`valm5_perc'")
 
 count if female==0 & inlist(education, 8, 9)
 local valm6_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C8=("`valm6_perc'")
 
//work status 
 count if female==1 & work_30days==1
 local valf7_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B9=("`valf7_perc'")
 
 count if female==1 & work_7days==1
 local valf8_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B10=("`valf8_perc'")
 
 count if female==0 & work_30days==1
 local valm7_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C9=("`valm7_perc'")
 
 count if female==0 & work_7days==1
 local valm8_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C10=("`valm8_perc'")
 
 count if female==1 & inlist(current_work_status,1, 2)
 local valf9_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B12=("`valf9_perc'")
 
 count if female==1 & inlist(current_work_status,3, 4, 7)
 local valf10_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B13=("`valf10_perc'")
 
 count if female==1 & current_work_status==6
 local valf11_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B14=("`valf11_perc'")
 
 count if female==1 & inlist(current_work_status, 8, 9)
 local valf12_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B15=("`valf12_perc'")
 
 count if female==1 & current_work_status==10
 local valf13_perc : display %9.2f (r(N)/`valf'*100)
 putexcel B16=("`valf13_perc'")
 
 count if female==0 & inlist(current_work_status,1, 2)
 local valm9_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C12=("`valm9_perc'")
 
 count if female==0 & inlist(current_work_status,3, 4, 7)
 local valm10_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C13=("`valm10_perc'")
 
 count if female==0 & current_work_status==6
 local valm11_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C14=("`valm11_perc'")
 
 count if female==0 & inlist(current_work_status, 8, 9)
 local valm12_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C15=("`valm12_perc'")
 
 count if female==0 & current_work_status==10
 local valm13_perc : display %9.2f (r(N)/`valm'*100)
 putexcel C16=("`valm13_perc'")
 
//reasons for not working 
 summ r_nowork_ill if female==1
 local valf14_perc : display %9.2f (r(mean)*100)
 putexcel B18=("`valf14_perc'") 
 
 summ r_nowork_chil if female==1
 local valf15_perc : display %9.2f (r(mean)*100)
 putexcel B19=("`valf15_perc'") 
 
 summ r_nowork_eld if female==1
 local valf16_perc : display %9.2f (r(mean)*100)
 putexcel B20=("`valf16_perc'") 
 
 summ r_nowork_chore if female==1
 local valf17_perc : display %9.2f (r(mean)*100)
 putexcel B21=("`valf17_perc'") 
 
 summ r_nowork_supp if female==1
 local valf18_perc : display %9.2f (r(mean)*100)
 putexcel B22=("`valf18_perc'") 
 
 summ r_nowork_avail if female==1
 local valf19_perc : display %9.2f (r(mean)*100)
 putexcel B23=("`valf19_perc'") 
 
 summ r_nowork_other if female==1
 local valf20_perc : display %9.2f (r(mean)*100)
 putexcel B24=("`valf20_perc'") 
 
 summ r_nowork_ill if female==0
 local valm14_perc : display %9.2f (r(mean)*100)
 putexcel C18=("`valm14_perc'") 
 
 summ r_nowork_chil if female==0
 local valm15_perc : display %9.2f (r(mean)*100)
 putexcel C19=("`valm15_perc'") 
 
 summ r_nowork_eld if female==0
 local valm16_perc : display %9.2f (r(mean)*100)
 putexcel C20=("`valm16_perc'") 
 
 summ r_nowork_chore if female==0
 local valm17_perc : display %9.2f (r(mean)*100)
 putexcel C21=("`valm17_perc'") 
 
 summ r_nowork_supp if female==0
 local valm18_perc : display %9.2f (r(mean)*100)
 putexcel C22=("`valm18_perc'") 
 
 summ r_nowork_avail if female==0
 local valm19_perc : display %9.2f (r(mean)*100)
 putexcel C23=("`valm19_perc'") 
 
 summ r_nowork_other if female==0
 local valm20_perc : display %9.2f (r(mean)*100)
 putexcel C24=("`valm20_perc'") 

 
*** Table 3 *** 
 reg M1C M2C, cluster(PSU)
 outreg2 using "$output\main\tables\table3.xls", adjr2 ctitle(Individual behavior (IB): Women do not work outside the house for pay) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace 

 foreach v of varlist M3C M4C M5Cbin {
	reg M1C `v', cluster(PSU)
	outreg2 using "$output\main\tables\table3.xls", adjr2 ctitle(Individual behavior (IB): Women do not work outside the house for pay) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 foreach v of varlist M2H M3H M4H M5Hbin {
	reg M1H `v', cluster(PSU)
	outreg2 using "$output\main\tables\table3.xls", adjr2 ctitle(IB: Women do not work in mix-gender environment) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 foreach v of varlist M2D M3D M4D M5Dbin {
	reg M1D `v', cluster(PSU)
	outreg2 using "$output\main\tables\table3.xls", adjr2 ctitle(IB: Women do not go outside the house unaccompanied) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 
*** Table 4 *** 
 reg M1A M2A, cluster(PSU)
 outreg2 using "$output\main\tables\table4.xls", adjr2 ctitle(Individual behavior (IB): It is a woman's primary responsibility to take care of the household) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace 

 foreach v of varlist M3A M4A M5Abin {
	reg M1A `v', cluster(PSU)
	outreg2 using "$output\main\tables\table4.xls", adjr2 ctitle(Individual behavior (IB): It is a woman's primary responsibility to take care of the household) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 foreach v of varlist M2B M3B M4B M5Bbin {
	reg M1B `v', cluster(PSU)
	outreg2 using "$output\main\tables\table4.xls", adjr2 ctitle(IB: A man is the sole financial provider for his family) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 foreach v of varlist M2G M3G M4G M5Gbin {
	reg M1G `v', cluster(PSU)
	outreg2 using "$output\main\tables\table4.xls", adjr2 ctitle(IB: Women do not leave young children with someone else when they go out to work for pay) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 } 
 
 
*** Table 5 ***  
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL mig_hh madheshi ib2.province 
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace

 reg flfp_outcome po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label 
 
 
 preserve 
 keep if female==1
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore 
 
 preserve 
 keep if female==0
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table5.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore
 
 
*** Table 6 ***  
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL mig_hh madheshi ib2.province 
 
 reg flfp_outcome M2A M3A `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace

 reg flfp_outcome M2B M3B `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 preserve 
 keep if female==1
 
 reg flfp_outcome M2A M3A `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome M2B M3B `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore 
 
 preserve 
 keep if female==0
 
 reg flfp_outcome M2A M3A `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome M2B M3B `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table6.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore 


*** Table 7 ***  
 local controls educ_years log_totinc_hhlessfem oth_fem_hh_lf adolescent_girls job_srch_res_nonet ib2.province
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\main\tables\table7.xls", adjr2 ctitle(Paid work) addtext(Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace
 
 
*** Table 8 *** 
 reg po_indexsum_hh female age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\main\tables\table8.xls", adjr2 ctitle(PNB Index - HH Roles) addtext(Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace 
 reg po_indexsum_public female age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\main\tables\table8.xls", adjr2 ctitle(PNB Index - Public Sphere) addtext(Clustering, YES) label

 reg ne_indexsum_hh female age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\main\tables\table8.xls", adjr2 ctitle(SNE Index - HH Roles) addtext(Clustering, YES) label
 reg ne_indexsum_public female age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\main\tables\table8.xls", adjr2 ctitle(SNE Index - Public Sphere) addtext(Clustering, YES) label

 reg sanc_indexsum female age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\main\tables\table8.xls", adjr2 ctitle(Sanctions Index) addtext(Clustering, YES) label
 
 
*** Table 9 *** 
 reg flfp_outcome N1__3, cluster(PSU)
 outreg2 using "$output\main\tables\table9.xls", adjr2 ctitle(Woman works outside for pay) addtext(Controls, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace


 foreach v of varlist N2__3 N1__6 N2__6 N1__13 N2__13 N1__14 N2__14 N1__15 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\main\tables\table9.xls", adjr2 ctitle(Woman works outside for pay) addtext(Controls, NO, Clustering, YES) label 
 } 
 
 preserve
 keep if female==1
 foreach v of varlist N1__3 N2__3 N1__6 N2__6 N1__13 N2__13 N1__14 N2__14 N1__15 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\main\tables\table9.xls", adjr2 ctitle(Woman works outside for pay) addtext(Controls, NO, Clustering, YES) label 
 }
 restore 
 
 preserve
 keep if female==0
 foreach v of varlist N1__3 N2__3 N1__6 N2__6 N1__13 N2__13 N1__14 N2__14 N1__15 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\main\tables\table9.xls", adjr2 ctitle(Woman works outside for pay) addtext(Controls, NO, Clustering, YES) label 
 }
 restore 
 
*** Table 10 ***  
 //Note: Text results summarized in this table are drawn from table 6 tables A.12, Annex A. 
 
}
 
********************************************************************************
*                       Part 2. FIGURES 							           *
********************************************************************************
if (`part_2' == 1) { 

*** Figure 1 *** 
 //Code not applicable; this is a text-only figure.
 
*** Figure 2 ***  
//Note: This generates the statistics represented in the graph. The graph was made in excel. 
 tabout pw_oe_spouse pw_oe_hhfam pw_oe_othfam pw_oe_comm using "$output\main\figures\figure2.xls", cells(col) oneway replace
 
*** Figure 3 ***  
//Note: This generates the statistics represented in the graph. The graph was made in excel. 
 putexcel set "$output\main\figures\figure3.xls", replace 
 
 putexcel B1=("Women do not/should not work outside for pay") /// 
 C1=("Women do not/should not work in mix-gender") ///
 D1=("Women working are subject to harassment") ///
 E1=("Women working is dishonorable") ///
 F1=("Women do not/should not go outside alone") ///
 A2=("Personal Beliefs") ///
 A3=("Social Normative Expectations") ///
 A4=("Social Empirical Expectations") ///
 A5=("Individual behavior") ///
 A6=("Sanctions") ///
  
 summ M2C
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B2=("`val1_perc'")
 
 summ M3C
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B3=("`val1_perc'")
 
 summ M4C
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B4=("`val1_perc'")
 
 summ M1C
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B5=("`val1_perc'")
 
 summ M5Cbin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B6=("`val1_perc'")
 
 summ M2H
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C2=("`val1_perc'")
 
 summ M3H
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C3=("`val1_perc'")
 
 summ M4H
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C4=("`val1_perc'")
 
 summ M1H
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C5=("`val1_perc'")
 
 summ M5Hbin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C6=("`val1_perc'")
 
 summ M2F
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D2=("`val1_perc'")
 
 summ M3F
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D3=("`val1_perc'")
 
 summ M4F
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D4=("`val1_perc'")
 
 summ M2E
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel E2=("`val1_perc'")
 
 summ M3E
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel E3=("`val1_perc'")
 
 summ M4E
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel E4=("`val1_perc'")
 
 summ M2D
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F2=("`val1_perc'")
 
 summ M3D
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F3=("`val1_perc'")
 
 summ M4D
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F4=("`val1_perc'")
 
 summ M1D
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F5=("`val1_perc'")
 
 summ M5Dbin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F6=("`val1_perc'")
 
 
*** Figure 4 ***  
//Note: This generates the statistics represented in the graph. The graph was made in excel. 
 putexcel set "$output\main\figures\figure4.xls", replace 
 
 putexcel B1=("Women do not /should not leave children") /// 
 C1=("HH work mainly done by women") ///
 D1=("Financially providing for family solely done by men") ///
 A2=("Personal Beliefs") ///
 A3=("Social Normative Expectations") ///
 A4=("Social Empirical Expectations") ///
 A5=("Individual behavior") ///
 A6=("Sanctions") ///
  
 summ M2G
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B2=("`val1_perc'")
 
 summ M3G
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B3=("`val1_perc'")
 
 summ M4G
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B4=("`val1_perc'")
 
 summ M1G
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B5=("`val1_perc'")
 
 summ M5Gbin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B6=("`val1_perc'")
 
 summ M2A
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C2=("`val1_perc'")
 
 summ M3A
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C3=("`val1_perc'")
 
 summ M4A
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C4=("`val1_perc'")
 
 summ M1A
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C5=("`val1_perc'")
 
 summ M5Abin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C6=("`val1_perc'")
 
 summ M2B
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D2=("`val1_perc'")
 
 summ M3B
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D3=("`val1_perc'")
 
 summ M4B
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D4=("`val1_perc'")
 
 summ M1B
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D5=("`val1_perc'")
 
 summ M5Bbin
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D6=("`val1_perc'")
 
 
*** Figure 5 ***  
//Note: This generates the statistics represented in the graph. The graph was made in excel.  
 
 putexcel set "$output\main\figures\figure5.xls", replace 
 
 putexcel A3=("Respondent approval") ///
 A4=("Community approval") /// 
 B1=("A woman's characteristics and roles") /// 
 B2=("Married") ///
 C2=("Leave child under 5 with family") ///
 D2=("Leave child under 5 with others") ///
 E2=("Unable to do HH chores") ///
 F2=("Educated") ///
 G1=("A woman's job characteristics") /// 
 G2=("Return after 5 pm") /// 
 H2=("Work not close to home") ///
 I2=("Travel outside") ///
 J2=("Physically demanding") ///
 K2=("Hotel/restaurant") ///
 L2=("Govt. job") ///
 M2=("Paid well") ///
 N1=("A woman's husband's employment status") ///
 N2=("Not working and no income") ///
 O2=("Previously unemployed but now working") ///
 P2=("Migrant husband does not remittance") ///
 
 summ N1__1
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B3=("`val1_perc'")
 summ N2__1
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel B4=("`val1_perc'")
 
 summ N1__2
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C3=("`val1_perc'")
 summ N2__2
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel C4=("`val1_perc'")
 
 summ N1__3
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D3=("`val1_perc'")
 summ N2__3
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel D4=("`val1_perc'")
 
 summ N1__6
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel E3=("`val1_perc'")
 summ N2__6
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel E4=("`val1_perc'")
 
 summ N1__10
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F3=("`val1_perc'")
 summ N2__10
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel F4=("`val1_perc'")
 
 summ N1__7
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel G3=("`val1_perc'")
 summ N2__7
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel G4=("`val1_perc'")
 
 summ N1__11
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel H3=("`val1_perc'")
 summ N2__11
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel H4=("`val1_perc'")
 
 summ N1__13
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel I3=("`val1_perc'")
 summ N2__13
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel I4=("`val1_perc'")
 
 summ N1__14
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel J3=("`val1_perc'")
 summ N2__14
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel J4=("`val1_perc'")
 
 summ N1__15
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel K3=("`val1_perc'")
 summ N2__15
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel K4=("`val1_perc'")
 
 summ N1__9
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel L3=("`val1_perc'")
 summ N2__9
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel L4=("`val1_perc'")
 
 summ N1__12
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel M3=("`val1_perc'")
 summ N2__12
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel M4=("`val1_perc'")
 
 summ N1__4
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel N3=("`val1_perc'")
 summ N2__4
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel N4=("`val1_perc'")
 
 summ N1__5
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel O3=("`val1_perc'")
 summ N2__5
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel O4=("`val1_perc'")
 
 summ N1__8
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel P3=("`val1_perc'")
 summ N2__8
 local val1_perc : display %9.2f (r(mean)*100)
 putexcel P4=("`val1_perc'")
 
}
 
********************************************************************************
// END OF DOFILE

