* **************************************************************************** *
* **************************************************************************** *
* Women's Labor Force Participation in Nepal:                                  *
* An Exploration of The Role of Social Norms                                   *
* Replication .do files 													   * 
* 03b: Data Analysis .do file                                                  *
* 2024                                                                         *
* **************************************************************************** *
* **************************************************************************** *

/*
* Author: Aishwarya Patil
* Program Purpose: This dofile reproduces analyses reported in the annex to 
*                  the paper. 
* Description: Key tasks performed by this dofile include:
- Generates tables and figures included in the annex to the paper.  
*
* Date last modified: June 2024
*------------------------------------------------------------------------------*
* Datasets Required: 
* - NPL_SN_FLFP_HH
* - NPL_SN_REGRESS
*
* Unique Identificator:
* - ID
* - ID_HH
*
* Outline: 
*  Part 1. Generate tables included in the annex to the paper.  
*  Part 2. Generate figures included in the annex to the paper.  
*/


********************************************************************************
*                       PREPARATION AND MAIN SETTINGS 
********************************************************************************
if 1{   
	
   local part_1    1    // Set to 1 to generate tables; 0 to skip 
   local part_2    1    // Set to 1 to generate figures; 0 to skip 
  
}


********************************************************************************
*                       Part 1. TABLES 							               *
********************************************************************************
if (`part_1' == 1) { 
 
*** Table A.1 ***
 //This table is not part of the suvrey data analysis; data comes from the Nepal Labor Force Survey, 2017-2018. Code available in misc_annex.do. 

*** Table A.2 *** 
 //This table is not part of the suvrey data analysis; data comes from the Nepal Labor Force Survey, 2017-2018, Code available in misc_annex.do. 

*** Table A.3 *** 
 //Code not applicable; this is a text-only table. 
 
*** Table A.4 ***
 *Load dataset 
 use "$data\final\NPL_SN_FLFP_HH.dta", clear
 
 //generate table 
 putexcel set "$output\annex\tables_annex\tableA.4.xls", replace 
 
 putexcel A1=("Variable") B1=("Full Sample Mean/(SE)") A2=("N") ///
 A3=("Total number of HH members") ///
 A5=("Total number of minors (under 18 years)") ///
 A7=("Total number of seniors (above 60 years)") ///
 A9=("Total number of disabled HH members") ///
 A11=("Number of respondent's children under 5 years") ///
 A13=("Number of respondent's children under 18 years") ///
 A15=("Number of working-age (>=18 & <=59) HH members") ///
 A17=("Number of female-working-age (>=18 & <=59) HH members") ///
 A19=("Number of male-working-age (>=18 & <=59) HH members") ///
 A21=("Indicator for a male member as head of HH") ///
 A23=("Mother-in-law lives in the HH ") ///
 A25=("Father-in-law lives in the HH ") ///
 A27=("At least one among MIL and FIL live in the HH ") ///
 A29=("Hindu") ///
 A31=("Buddhist") ///
 A33=("Muslim (religion)") ///
 A35=("Christian") ///
 A37=("Khas & Aryan") ///
 A39=("Adibasi & Janajati") ///
 A41=("Madhesi (Non dalit)") ///
 A43=("Dalit") ///
 A45=("Muslim (ethnicity)") ///
 A47=("Rural ") ///
 A49=("Mountain") ///
 A51=("Hill") ///
 A53=("Terai") ///
 
 count 
 local valn = r(N)
 putexcel B2=("`valn'")
 
 summ hh_members
 local val1 : display %3.2f r(mean) 
 putexcel B3=("`val1'")
 local val2 : display %3.2f r(sd)
 putexcel B4=("`val2'")
 
 summ hh_minors
 local val3 : display %3.2f r(mean)
 putexcel B5=("`val3'")
 local val4 : display %3.2f r(sd)
 putexcel B6=("`val4'")
 
 summ hh_seniors
 local val5 : display %3.2f r(mean)
 putexcel B7=("`val5'")
 local val6 : display %3.2f r(sd)
 putexcel B8=("`val6'")
 
 summ hh_disabled
 local val7 : display %3.2f r(mean)
 putexcel B9=("`val7'")
 local val8 : display %3.2f r(sd)
 putexcel B10=("`val8'")
 
 summ count_childrenunder5
 local val9 : display %3.2f r(mean)
 putexcel B11=("`val9'")
 local val10 : display %3.2f r(sd)
 putexcel B12=("`val10'")
 
 summ count_childrenunder18
 local val11 : display %3.2f r(mean)
 putexcel B13=("`val11'")
 local val12 : display %3.2f r(sd)
 putexcel B14=("`val12'")
 
 summ count_workingage
 local val13 : display %3.2f r(mean)
 putexcel B15=("`val13'")
 local val14 : display %3.2f r(sd)
 putexcel B16=("`val14'")
 
 summ count_workingagefem
 local val15 : display %3.2f r(mean)
 putexcel B17=("`val15'")
 local val16 : display %3.2f r(sd)
 putexcel B18=("`val16'")
 
 summ count_workingagemale
 local val17 : display %3.2f r(mean)
 putexcel B19=("`val17'")
 local val18 : display %3.2f r(sd)
 putexcel B20=("`val18'")
 
 summ MaleHHhead
 local val19 : display %3.2f r(mean)
 putexcel B21=("`val19'")
 local val20 : display %3.2f r(sd)
 putexcel B22=("`val20'")
 
 summ MIL
 local val21 : display %3.2f r(mean)
 putexcel B23=("`val21'")
 local val22 : display %3.2f r(sd)
 putexcel B24=("`val22'")
 
 summ FIL
 local val23 : display %3.2f r(mean)
 putexcel B25=("`val23'")
 local val24 : display %3.2f r(sd)
 putexcel B26=("`val24'")
 
 summ PIL
 local val25 : display %3.2f r(mean)
 putexcel B27=("`val25'") 
 local val26 : display %3.2f r(sd)
 putexcel B28=("`val26'")
 
 *Load dataset 
 use "$data\final\NPL_SN_REGRESS.dta", clear
 
 tabulate religion_family, gen(religion_tab)
 
 summ religion_tab1
 local val27 : display %3.2f r(mean)
 putexcel B29=("`val27'")
 local val28 : display %3.2f r(sd)
 putexcel B30=("`val28'")
 
 summ religion_tab2
 local val29 : display %3.2f r(mean)
 putexcel B31=("`val29'")
 local val30 : display %3.2f r(sd)
 putexcel B32=("`val30'")
 
 summ religion_tab3
 local val31 : display %3.2f r(mean)
 putexcel B33=("`val31'")
 local val32 : display %3.2f r(sd)
 putexcel B34=("`val32'")
 
 summ religion_tab4
 local val33 : display %3.2f r(mean)
 putexcel B35=("`val33'")
 local val34 : display %3.2f r(sd)
 putexcel B36=("`val34'")
 
 tabulate ethnicity, gen(ethnicity_tab) 
 
 summ ethnicity_tab1
 local val35 : display %3.2f r(mean)
 putexcel B37=("`val35'")
 local val36 : display %3.2f r(sd)
 putexcel B38=("`val36'")
 
 summ ethnicity_tab2
 local val37 : display %3.2f r(mean)
 putexcel B39=("`val37'")
 local val38 : display %3.2f r(sd)
 putexcel B40=("`val38'")
  
 summ ethnicity_tab3
 local val39 : display %3.2f r(mean)
 putexcel B41=("`val39'")
 local val40 : display %3.2f r(sd)
 putexcel B42=("`val40'")
   
 summ ethnicity_tab4
 local val41 : display %3.2f r(mean)
 putexcel B43=("`val41'")
 local val42 : display %3.2f r(sd)
 putexcel B44=("`val42'")
	
 summ ethnicity_tab5
 local val43 : display %3.2f r(mean)
 putexcel B45=("`val43'")
 local val44 : display %3.2f r(sd)
 putexcel B46=("`val44'")
 
 tabulate locality, gen(locality_tab)
 
 summ locality_tab2
 local val45 : display %3.2f r(mean)
 putexcel B47=("`val45'")
 local val46 : display %3.2f r(sd)
 putexcel B48=("`val46'")

 tabulate ecological_zone, gen(ecological_tab)
 summ ecological_tab1
 local val47 : display %3.2f r(mean)
 putexcel B49=("`val47'")
 local val48 : display %3.2f r(sd)
 putexcel B50=("`val48'")
 
 summ ecological_tab2
 local val49 : display %3.2f r(mean)
 putexcel B51=("`val49'")
 local val50 : display %3.2f r(sd)
 putexcel B52=("`val50'")
 
 summ ecological_tab3
 local val51 : display %3.2f r(mean)
 putexcel B53=("`val51'")
 local val52 : display %3.2f r(sd)
 putexcel B54=("`val52'")
 
 drop religion_tab* ethnicity_tab* locality_tab* ecological_tab*
 
 
*** Table A.5 ***
 *Load dataset 
 use "$data\final\NPL_SN_FLFP_HH.dta", clear
 
 //generate table 
 putexcel set "$output\annex\tables_annex\tableA.5.xls", replace 
 
 putexcel A1=("Variable (in percent)") B1=("Full Sample Mean") ///
 C1=("Male Mean") D1=("Female Mean") ///
 A2=("Share of HH members who are of working age") ///
 A3=("Share of HH members who are of working age in labor force") ///
 A4=("Share of HH members who are of working age out of labor force") ///
 A5=("Out of those in labor force, share of those who are:") ///
 A6=("Self-employed/own-account worker (no employees) ") ///
 A7=("Business owner/employer with at least 1 employee") ///
 A8=("Salaried/wage employee ") ///
 A9=("Army") ///
 A10=("Student who also works") ///
 A11=("Unpaid worker in the family business") ///
 A12=("Paid worker in the family business") ///
 A13=("Does not work but is looking for work")
 
 summ share_workingage
 local val1 : display %3.2f r(mean)
 putexcel B2=("`val1'")
 
 summ share_workingagemale
 local valm1 : display %3.2f r(mean)
 putexcel C2=("`valm1'")
 
 summ share_workingagefem
 local valf1 : display %3.2f r(mean)
 putexcel D2=("`valf1'")
 
 summ share_lf
 local val2 : display %3.2f r(mean)
 putexcel B3=("`val2'")
 
 summ share_lf_male
 local valm2 : display %3.2f r(mean)
 putexcel C3=("`valm2'")
 
 summ share_lf_fem
 local valf2 : display %3.2f r(mean)
 putexcel D3=("`valf2'")

 summ share_lf_oaw
 local val3 : display %3.2f r(mean)
 putexcel B6=("`val3'")
 
 summ share_oaw_lf_m
 local valfm3 : display %3.2f r(mean)
 putexcel C6=("`valfm3'")
 
 summ share_oaw_lf_f
 local valf3 : display %3.2f r(mean)
 putexcel D6=("`valf3'")
 
 summ share_lf_emp
 local val4 : display %3.2f r(mean)
 putexcel B7=("`val4'")
 
 summ share_emp_lf_m
 local valfm4 : display %3.2f r(mean)
 putexcel C7=("`valfm4'")
 
 summ share_emp_lf_f
 local valf4 : display %3.2f r(mean)
 putexcel D7=("`valf4'")
 
 summ share_lf_wage
 local val5 : display %3.2f r(mean)
 putexcel B8=("`val5'")
 
 summ share_wage_lf_m
 local valfm5 : display %3.2f r(mean)
 putexcel C8=("`valfm5'")
 
 summ share_wage_lf_f
 local valf5 : display %3.2f r(mean)
 putexcel D8=("`valf5'")
 
 summ share_lf_army
 local val6 : display %3.2f r(mean)
 putexcel B9=("`val6'")
 
 summ share_army_lf_m
 local valfm6 : display %3.2f r(mean)
 putexcel C9=("`valfm6'")
 
 summ share_army_lf_f
 local valf6 : display %3.2f r(mean)
 putexcel D9=("`valf6'") 

 summ share_lf_studwork
 local val7 : display %3.2f r(mean)
 putexcel B10=("`val7'")
 
 summ share_studwork_lf_m
 local valfm7 : display %3.2f r(mean)
 putexcel C10=("`valfm7'")
 
 summ share_studwork_lf_f
 local valf7 : display %3.2f r(mean)
 putexcel D10=("`valf7'") 
 
 summ share_lf_unpfam
 local val8 : display %3.2f r(mean)
 putexcel B11=("`val8'")
 
 summ share_unpfam_lf_m
 local valfm8 : display %3.2f r(mean)
 putexcel C11=("`valfm8'")
 
 summ share_unpfam_lf_f
 local valf8 : display %3.2f r(mean)
 putexcel D11=("`valf8'")  
 
 summ share_lf_pfam
 local val9 : display %3.2f r(mean)
 putexcel B12=("`val9'")
 
 summ share_pfam_lf_m
 local valfm9 : display %3.2f r(mean)
 putexcel C12=("`valfm9'")
 
 summ share_pfam_lf_f
 local valf9 : display %3.2f r(mean)
 putexcel D12=("`valf9'")  
 
 summ share_lf_noworkyeslook
 local val10 : display %3.2f r(mean)
 putexcel B13=("`val10'")
 
 summ share_noworkyeslook_lf_m
 local valfm10 : display %3.2f r(mean)
 putexcel C13=("`valfm10'")
 
 summ share_noworkyeslook_lf_f
 local valf10 : display %3.2f r(mean)
 putexcel D13=("`valf10'")  
 
 summ share_outlf
 local val11 : display %3.2f r(mean)
 putexcel B4=("`val11'")
 
 summ share_outlf_m
 local valm11 : display %3.2f r(mean)
 putexcel C4=("`valm11'")
 
 summ share_outlf_f
 local valf11 : display %3.2f r(mean)
 putexcel D4=("`valf11'")
 
 
*** Table A.6 ***
 //generate table 
 putexcel set "$output\annex\tables_annex\tableA.6.xls", replace 
 
 putexcel A1=("Variable") B1=("N") C1=("Full Sample Mean/(SE)") /// 
 A2=("Earned income, reported by female") ///
 A4=("International remittances, reported by female") ///
 A6=("Domestic remittances, reported by female") ///
 A8=("Other transfers from family or friends, reported by female") ///
 A10=("Safety nets, reported by female") ///
 A12=("Savings or selling assets, reported by female ") ///
 A14=("Loan, reported by female") ///
 A16=("Earned income amount, reported by female") ///
 A18=("International remittances amount, reported by female") ///
 A20=("Domestic remittances amount, reported by female") ///
 A22=("Other transfers from family or friends amount, reported by female") ///
 A24=("Safety nets amount, reported by female") ///
 A26=("Savings or selling assets amount, reported by female") ///
 A28=("Loan amount, reported by female") ///
 A30=("Total income of HH reported by female") 
 
 summ earn_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B2=("`val1'")
 putexcel C2=("`val2'")
 putexcel C3=("`val3'")
 
 summ intrem_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B4=("`val1'")
 putexcel C4=("`val2'")
 putexcel C5=("`val3'")
 
 summ domrem_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B6=("`val1'")
 putexcel C6=("`val2'")
 putexcel C7=("`val3'")
 
 summ transf_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B8=("`val1'")
 putexcel C8=("`val2'")
 putexcel C9=("`val3'")
 
 summ safety_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B10=("`val1'")
 putexcel C10=("`val2'")
 putexcel C11=("`val3'")
 
 summ savass_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B12=("`val1'")
 putexcel C12=("`val2'")
 putexcel C13=("`val3'")
 
 summ loan_inc_d_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B14=("`val1'")
 putexcel C14=("`val2'")
 putexcel C15=("`val3'")
 
 summ earn_inc_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B16=("`val1'")
 putexcel C16=("`val2'")
 putexcel C17=("`val3'")
  
 summ intrem_inc_f if ID_HH!="HH5348" //remove outlier (amount==220000)
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B18=("`val1'")
 putexcel C18=("`val2'")
 putexcel C19=("`val3'")
  
 summ domrem_inc_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B20=("`val1'")
 putexcel C20=("`val2'")
 putexcel C21=("`val3'") 
 
 summ transf_inc_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B22=("`val1'")
 putexcel C22=("`val2'")
 putexcel C23=("`val3'")  
 
 summ safety_inc_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B24=("`val1'")
 putexcel C24=("`val2'")
 putexcel C25=("`val3'")  
 
 summ savass_inc_f
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B26=("`val1'")
 putexcel C26=("`val2'")
 putexcel C27=("`val3'") 
 
 summ loan_inc_f 
 local val1 = r(N)
 local val2 : display %9.2f r(mean)
 local val3 : display %9.2f r(sd)
 putexcel B28=("`val1'")
 putexcel C28=("`val2'")
 putexcel C29=("`val3'") 
 
 summ tot_inc_f 
 local val1 = r(N)
 local val2 : display %3.2f r(mean)
 local val3 : display %3.2f r(sd)
 putexcel B30=("`val1'")
 putexcel C30=("`val2'")
 putexcel C31=("`val3'") 
 
 
*** Table A.7 *** 
//Note: The following code generates 6 sub-tables, from tableA.7_1 to tableA.7_6, even though combined to present in the paper.

 *Load dataset 
 use "$data\final\NPL_SN_REGRESS.dta", clear
 
 //generate tables
 iebaltab age work_30days work_7days ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_1.xls") replace rowvarlabels
 
 putexcel set "$output\annex\tables_annex\tableA.7_1.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ age
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'")
 
 summ work_30days
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H6=("`val1'")
 putexcel H7=("`val2'")
 
 summ work_7days
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H8=("`val1'")
 putexcel H9=("`val2'")
 
 preserve
 keep if female==0
 summ ever_migrated_male 
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel A12=("Ever migrated (self - asked only to males)")
 putexcel C12=("`val1'")
 putexcel C13=("`val2'")
 restore 
 
 preserve
 keep if female==1
 summ ever_migrated_spouse
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel A15=("Spouse ever migrated (asked only to females)")
 putexcel E15=("`val1'")
 putexcel E16=("`val2'")
 restore 
 
 preserve
 keep if work_30days==1
 iebaltab paidwork_30days ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_2.xls") replace rowvarlabels

 putexcel set "$output\annex\tables_annex\tableA.7_2.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ paidwork_30days
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'")
 restore 
 
 preserve
 keep if work_7days==1
 iebaltab paidwork_7days ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_3.xls") replace rowvarlabels

 putexcel set "$output\annex\tables_annex\tableA.7_3.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ paidwork_7days
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'")
 restore 
 
 preserve
 keep if work_30days==0
 iebaltab work_ever ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_4.xls") replace rowvarlabels

 putexcel set "$output\annex\tables_annex\tableA.7_4.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ work_ever
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'")
 restore 
 
 iebaltab work_inc_amt ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_5.xls") replace rowvarlabels

 putexcel set "$output\annex\tables_annex\tableA.7_5.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ work_inc_amt
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'")
 
 
 tabulate work_type, gen(work_type_tab)
  
 iebaltab work_hours_weekly work_inside work_written_contract work_emp_ss work_type_tab* work_agri ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.7_6.xls") replace rowvarlabels
 
 putexcel set "$output\annex\tables_annex\tableA.7_6.xls", modify  
 putexcel H3=("Full Sample Mean/(SE)")
 
 summ work_hours_weekly
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H4=("`val1'")
 putexcel H5=("`val2'") 
 
 summ work_inside
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H6=("`val1'")
 putexcel H7=("`val2'") 
 
 summ work_written_contract
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H8=("`val1'")
 putexcel H9=("`val2'") 
 
 summ work_emp_ss
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H10=("`val1'")
 putexcel H11=("`val2'") 
 
 summ work_type_tab1
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H12=("`val1'")
 putexcel H13=("`val2'")
 
 summ work_type_tab2
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H14=("`val1'")
 putexcel H15=("`val2'")
 
 summ work_type_tab3
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H16=("`val1'")
 putexcel H17=("`val2'")
 
 summ work_type_tab4
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H18=("`val1'")
 putexcel H19=("`val2'")
 
 summ work_type_tab5
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H20=("`val1'")
 putexcel H21=("`val2'")
 
 summ work_type_tab6
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H22=("`val1'")
 putexcel H23=("`val2'")
 
 summ work_type_tab7
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H24=("`val1'")
 putexcel H25=("`val2'")
 
 summ work_agri
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel H26=("`val1'")
 putexcel H27=("`val2'") 

 drop work_type_tab*
 
 
*** Table A.8 *** 
 putexcel set "$output\annex\tables_annex\tableA.8.xls", replace 
 
 putexcel A1=("Aspiration statement") B1=("Share of respondents who agree Mean/(SE)") /// 
 A2=("I would want my daughter to work outside the house and earn a living.") ///
 A4=("I would want my daughter to work outside the house and earn a living, even when she is married.") ///
 A6=("I would want my daughter to work outside the house and earn a living, even when she has school-going children.") ///
 A8=("I would want my daughter in law to work outside the house and earn a living.") ///
 A10=("I would want my daughter in law to work outside the house and earn a living, even when she has school-going children.") 
 
 summ binM6A 
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel B2=("`val1'")
 putexcel B3=("`val2'")
 
 summ binM6B 
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel B4=("`val1'")
 putexcel B5=("`val2'")
 
 summ binM6C 
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel B6=("`val1'")
 putexcel B7=("`val2'")
 
 summ binM6D 
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel B8=("`val1'")
 putexcel B9=("`val2'")
 
 summ binM6E
 local val1 : display %3.2f r(mean)
 local val2 : display %3.2f r(sd)
 putexcel B10=("`val1'")
 putexcel B11=("`val2'")
 
 
*** Table A.9 *** 
 reg flfp_outcome M2A, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace 

 foreach v of varlist M2B M2C M2D M2E M2F M2G M2H M3A M3B M3C M3D M3E M3F M3G M3H M4A M4B M4C M4D M4E M4F M4G M4H M5Abin M5Bbin M5Cbin M5Dbin M5Gbin M5Hbin {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 
 preserve 
 keep if female==1 
  reg flfp_outcome M2A, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label 

 foreach v of varlist M2B M2C M2D M2E M2F M2G M2H M3A M3B M3C M3D M3E M3F M3G M3H M4A M4B M4C M4D M4E M4F M4G M4H M5Abin M5Bbin M5Cbin M5Dbin M5Gbin M5Hbin {
 reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 restore 
 
 preserve 
 keep if female==0 
  reg flfp_outcome M2A, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label 

 foreach v of varlist M2B M2C M2D M2E M2F M2G M2H M3A M3B M3C M3D M3E M3F M3G M3H M4A M4B M4C M4D M4E M4F M4G M4H M5Abin M5Bbin M5Cbin M5Dbin M5Gbin M5Hbin {
 reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.9.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 }
 restore
 
 
*** Table A.10 *** 
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL mig_hh madheshi

 reg flfp_outcome sanc_indexsum `controls' ib2.province, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label replace 
 reg flfp_outcome sanc_indexsum, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 
 preserve
 keep if female==1
 reg flfp_outcome sanc_indexsum `controls' ib2.province, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label 
 reg flfp_outcome sanc_indexsum, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 restore 
 
 preserve
 keep if female==0
 reg flfp_outcome sanc_indexsum `controls' ib2.province, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label 
 reg flfp_outcome sanc_indexsum, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.10.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 restore 
 
 
*** Table A.11 ***  
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace

 reg flfp_outcome po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label 
 
 preserve 
 keep if female==1
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label

 reg flfp_outcome po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label
 restore 
 
 preserve 
 keep if female==0
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label

 reg flfp_outcome po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label
 
 reg flfp_outcome po_indexsum_hh ne_indexsum_hh po_indexsum_public ne_indexsum_public, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.11.xls", adjr2 ctitle(Paid work) addtext(Controls, NO, Regional FE, NO, Clustering, YES) label
 restore 
 
*** Table A.12 *** 
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL mig_hh madheshi ib2.province
  
 reg flfp_outcome M2C M3C `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace

 reg flfp_outcome M2D M3D `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2E M3E `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2F M3F `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2G M3G `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2H M3H `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
  
 preserve 
 keep if female==1
 reg flfp_outcome M2C M3C `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label 

 reg flfp_outcome M2D M3D `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2E M3E `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2F M3F `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2G M3G `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2H M3H `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore 
 
 preserve 
 keep if female==0
 reg flfp_outcome M2C M3C `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label 

 reg flfp_outcome M2D M3D `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2E M3E `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2F M3F `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2G M3G `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 reg flfp_outcome M2H M3H `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.12.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 restore  
 
 
*** Table A.13 ***  
 //Table 13.1
 preserve
 keep if female==1
 reg po_indexsum_hh age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.1.xls", adjr2 ctitle(PNB Index - HH Roles) addtext(Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace 
 reg po_indexsum_public age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.1.xls", adjr2 ctitle(PNB Index - Public Sphere) addtext(Clustering, YES) label

 reg ne_indexsum_hh age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.1.xls", adjr2 ctitle(SNE Index - HH Roles) addtext(Clustering, YES) label
 reg ne_indexsum_public age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.1.xls", adjr2 ctitle(SNE Index - Public Sphere) addtext(Clustering, YES) label

 reg sanc_indexsum age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi mig_hh PIL, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.1.xls", adjr2 ctitle(Sanctions Index) addtext(Clustering, YES) label
 restore 
 
 //Table 13.2
 preserve 
 keep if female==0
 reg po_indexsum_hh age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi PIL ever_mig_male, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.2.xls", adjr2 ctitle(PNB Index - HH Roles) addtext(Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label 
 reg po_indexsum_public age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi PIL ever_mig_male, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.2.xls", adjr2 ctitle(PNB Index - Public Sphere) addtext(Clustering, YES) label

 reg ne_indexsum_hh age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi PIL ever_mig_male, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.2.xls", adjr2 ctitle(SNE Index - HH Roles) addtext(Clustering, YES) label
 reg ne_indexsum_public age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi PIL ever_mig_male, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.2.xls", adjr2 ctitle(SNE Index - Public Sphere) addtext(Clustering, YES) label

 reg sanc_indexsum age_sq educ_years child_under5 urban log_totinc_hhlessfem ib2.province madheshi PIL ever_mig_male, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.13.2.xls", adjr2 ctitle(Sanctions Index) addtext(Clustering, YES) label
 restore
 
 
*** Table A.14 *** 
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL mig_hh ib2.province  
 
 reg flfp_outcome i.madheshi##c.po_indexsum_hh i.madheshi##c.ne_indexsum_hh `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.14.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace 

 reg flfp_outcome i.madheshi##c.po_indexsum_public i.madheshi##c.ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.14.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome i.madheshi##c.po_indexsum_hh i.madheshi##c.ne_indexsum_hh i.madheshi##c.po_indexsum_public i.madheshi##c.ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.14.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label  
 
 
*** Table A.15 ***
 local controls age_sq educ_years child_under5 urban log_totinc_hh PIL madheshi ib2.province    
 
 reg flfp_outcome i.mig_hh##c.po_indexsum_hh i.mig_hh##c.ne_indexsum_hh `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.15.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) addnote(SEs clustered at ward level, 2.province==Bagmati) label replace 

 reg flfp_outcome i.mig_hh##c.po_indexsum_public i.mig_hh##c.ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.15.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label

 reg flfp_outcome i.mig_hh##c.po_indexsum_hh i.mig_hh##c.ne_indexsum_hh i.mig_hh##c.po_indexsum_public i.mig_hh##c.ne_indexsum_public `controls', cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.15.xls", adjr2 ctitle(Paid work) addtext(Controls, YES, Regional FE, YES, Clustering, YES) label
 
 
*** Table A.16 *** 
 putexcel set "$output\annex\tables_annex\tableA.16.xls", replace 
 
 putexcel A1=("Comparison scenarios") B1=("p-values associated with t-test") /// 
 B2=("Full sample") C2=("Females only sample") D2=("Males only sample") ///
 A3=("1. Change SNE only: low-low vs highlow (conservative SEE & SNE vs. liberal SEE & conservative SNE)") ///
 A4=("2. Change both SEE and SNE: low-low vs high-high (conservative SEE & SNE vs. liberal SEE & SNE)") ///
 A5=("3. Change SNE only: low-low vs low-high (conservative SEE & SNE vs. conservative SEE & liberal SNE)")
 
 ttest v_work_ll==v_work_hl
 local val1 : display %3.2f r(p)
 putexcel B3=("`val1'")
 
 ttest v_work_ll==v_work_hh
 local val2 : display %3.2f r(p)
 putexcel B4=("`val2'")
 
 ttest v_work_ll==v_work_lh
 local val3 : display %3.2f r(p)
 putexcel B5=("`val3'")
 
 ttest v_work_ll==v_work_hl if female==1
 local val1 : display %3.2f r(p)
 putexcel C3=("`val1'")
 
 ttest v_work_ll==v_work_hh if female==1
 local val2 : display %3.2f r(p)
 putexcel C4=("`val2'")
 
 ttest v_work_ll==v_work_lh if female==1
 local val3 : display %3.2f r(p)
 putexcel C5=("`val3'")

 ttest v_work_ll==v_work_hl if female==0
 local val1 : display %3.2f r(p)
 putexcel D3=("`val1'")
 
 ttest v_work_ll==v_work_hh if female==0
 local val2 : display %3.2f r(p)
 putexcel D4=("`val2'")
 
 ttest v_work_ll==v_work_lh if female==0
 local val3 : display %3.2f r(p)
 putexcel D5=("`val3'")

 
*** Table A.17 *** 
 reg flfp_outcome N1__1, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) addnote(SEs clustered at ward level) label replace


 foreach v of varlist N1__2 N1__3 N1__4 N1__5 N1__6 N1__7 N1__8 N1__9 N1__10 N1__11 N1__12 N1__13 N1__14 N1__15 N2__1 N2__2 N2__3 N2__4 N2__5 N2__6 N2__7 N2__8 N2__9 N2__10 N2__11 N2__12 N2__13 N2__14 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) label 
 }

 preserve 
 keep if female==1
 reg flfp_outcome N1__1, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) addnote(SEs clustered at ward level) label


 foreach v of varlist N1__2 N1__3 N1__4 N1__5 N1__6 N1__7 N1__8 N1__9 N1__10 N1__11 N1__12 N1__13 N1__14 N1__15 N2__1 N2__2 N2__3 N2__4 N2__5 N2__6 N2__7 N2__8 N2__9 N2__10 N2__11 N2__12 N2__13 N2__14 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) label 
 }
 restore 

 preserve 
 keep if female==0
 reg flfp_outcome N1__1, cluster(PSU)
 outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) addnote(SEs clustered at ward level) label

 foreach v of varlist N1__2 N1__3 N1__4 N1__5 N1__6 N1__7 N1__8 N1__9 N1__10 N1__11 N1__12 N1__13 N1__14 N1__15 N2__1 N2__2 N2__3 N2__4 N2__5 N2__6 N2__7 N2__8 N2__9 N2__10 N2__11 N2__12 N2__13 N2__14 N2__15 {
	reg flfp_outcome `v', cluster(PSU)
	outreg2 using "$output\annex\tables_annex\tableA.17.xls", adjr2 ctitle(Female works for pay outside the home) addtext(Controls, NO, Clustering, YES) label 
 }
 restore 
 
 
*** Table A.18 ***  
 //Table 18.1
 iebaltab N1__1 N1__2 N1__3 N1__4 N1__5 N1__6 N1__7 N1__8 N1__9 N1__10 N1__11 N1__12 N1__13 N1__14 N1__15 N2__1 N2__2 N2__3 N2__4 N2__5 N2__6 N2__7 N2__8 N2__9 N2__10 N2__11 N2__12 N2__13 N2__14 N2__15 ///
, groupvar(work_30_female) savexlsx("$output\annex\tables_annex\tableA.18.1.xls") replace rowvarlabels

 //Table 18.2
 iebaltab N1__1 N1__2 N1__3 N1__4 N1__5 N1__6 N1__7 N1__8 N1__9 N1__10 N1__11 N1__12 N1__13 N1__14 N1__15 N2__1 N2__2 N2__3 N2__4 N2__5 N2__6 N2__7 N2__8 N2__9 N2__10 N2__11 N2__12 N2__13 N2__14 N2__15 ///
, groupvar(mig_hh_female) savexlsx("$output\annex\tables_annex\tableA.18.2.xls") replace rowvarlabels
 
 //Table 18.3
 iebaltab N1__6 N2__6 N1__7 N2__7 N1__11 N2__11 ///
, groupvar(female) savexlsx("$output\annex\tables_annex\tableA.18.3.xls") replace rowvarlabels 
 
}

********************************************************************************
*                       Part 2. FIGURES 							           *
********************************************************************************
if (`part_2' == 1) { 

 set graphics off
 
*** Figure B.1 *** 
 //Code not applicable; this is a text-only figure.

*** Figure B.2 *** 
 kdensity po_indexsum_hh if female==1, ///
 plot((kdensity po_indexsum_hh if female==0)) ///
 legend(label(1 "Female") label(2 "Male")) ///
 legend(position(6) col(2) size(vsmall)) ///
 title("Personal Beliefs Index - Gender roles within the home", size(medium) span) ///
 xtitle("PB Index - Gender Roles", size(tiny)) ///
 ytitle("Density", size(tiny))
 graph export "$output\annex\figures_annex\figureb.2a.png", as(png) replace 
 
 kdensity ne_indexsum_hh if female==1, ///
 plot((kdensity ne_indexsum_hh if female==0)) ///
 legend(label(1 "Female") label(2 "Male")) ///
 legend(position(6) col(2) size(vsmall)) ///
 title("Normative Expectations Index - Gender roles within the home", size(medium) span) ///
 xtitle("SNE Index - Gender Roles", size(tiny)) ///
 ytitle("Density", size(tiny))
 graph export "$output\annex\figures_annex\figureb.2b.png", as(png) replace 
 
 kdensity po_indexsum_public if female==1, ///
 plot((kdensity po_indexsum_public if female==0)) ///
 legend(label(1 "Female") label(2 "Male")) ///
 legend(position(6) col(2) size(vsmall)) ///
 title("Personal Beliefs Index - Women in the public sphere", size(medium) span) ///
 xtitle("PB Index - Public Sphere", size(tiny)) ///
 ytitle("Density", size(tiny)) 
 graph export "$output\annex\figures_annex\figureb.2c.png", as(png) replace

 kdensity ne_indexsum_public if female==1, ///
 plot((kdensity ne_indexsum_public if female==0)) ///
 legend(label(1 "Female") label(2 "Male")) ///
 legend(position(6) col(2) size(vsmall)) ///
 title("Normative Expectations Index - Women in the public sphere", size(medium) span) ///
 xtitle("SNE Index - Public Sphere", size(tiny)) ///
 ytitle("Density", size(tiny)) 
 graph export "$output\annex\figures_annex\figureb.2d.png", as(png) replace
 
 kdensity sanc_indexsum if female==1, ///
 plot((kdensity sanc_indexsum if female==0)) ///
 legend(label(1 "Female") label(2 "Male")) ///
 legend(position(6) col(2) size(vsmall)) ///
 title("Sanctions Index", size(medium) span) ///
 xtitle("Sanc. Index", size(tiny)) ///
 ytitle("Density", size(tiny))
 graph export "$output\annex\figures_annex\figureb.2e.png", as(png) replace



*** Figure B.3 *** 
//Note: This generates the statistics represented in the graphs. The graphs were made in excel.

 //Figure B.3(a)
 tabout le_oe_spouse le_oe_hhfam le_oe_othfam le_oe_comm using "$output\annex\figures_annex\figureb.3(a)1.xls", cells(col) oneway replace
 tabout le_oe_spouse le_oe_hhfam le_oe_othfam le_oe_comm if female==1 using "$output\annex\figures_annex\figureb.3(a)2.xls", cells(col) oneway replace
 tabout le_oe_spouse le_oe_hhfam le_oe_othfam le_oe_comm if female==0 using "$output\annex\figures_annex\figureb.3(a)3.xls", cells(col) oneway replace

 //Figure B.3(b)
 tabout pw_oe_spouse pw_oe_hhfam pw_oe_othfam pw_oe_comm if female==1 using "$output\annex\figures_annex\figureb.3(b)1.xls", cells(col) oneway replace
 tabout pw_oe_spouse pw_oe_hhfam pw_oe_othfam pw_oe_comm if female==0 using "$output\annex\figures_annex\figureb.3(b)2.xls", cells(col) oneway replace
 
}

********************************************************************************
// END OF DOFILE 
 